.. _fluent_pages.pagetypes.fluentpage.models:

fluent_pages.pagetypes.fluentpage.models
========================================

.. automodule:: fluent_pages.pagetypes.fluentpage.models

The ``AbstractFluentPage`` class
--------------------------------

.. autoclass:: fluent_pages.pagetypes.fluentpage.models.AbstractFluentPage
   :members:

The ``FluentPage`` class
------------------------

.. autoclass:: fluent_pages.pagetypes.fluentpage.models.FluentPage
   :members:
